#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_DIVIDES_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_DIVIDES_HPP_INCLUDED

#include <boost/simd/operator/include/functions/simd/divides.hpp>

#endif
